# MetroloJ-for-python
MetroloJ is an ImageJ software plugin that helps keeping track of microscopes' performances by extracting 4 relevant estimators out of standardized images, acquired from test samples[1]. \
The present project aims to implement MetroloJ functionalities on python. 

# metroloj package
'metroloj' is a pip package that provides functions to analyze microscope images.

# requirements
in a virtual envirenement, run the following command:
```python -m pip install -r metroloj/requirements.txt```

#### References
[1] https://imagejdocu.tudor.lu/plugin/analysis/metroloj/start
